.. _gala-supporting:

***************
Other Documents
***************

This section contains additional supporting documents for `gala`. Currently, this only
includes a tutorial-style document that explains how the Milky Way potential models
provided in `gala` were constructed and fitted to data.

.. The _tutorials.rst file is auto-generated in conf.py. Add new tutorials to
.. the list of files in conf.py

.. include:: _supporting.rst
